(function (global, factory) {
    typeof exports === 'object' && typeof module !== 'undefined' ? factory(exports, require('@angular/core'), require('@angular/common')) :
    typeof define === 'function' && define.amd ? define('ngx-highlight-words', ['exports', '@angular/core', '@angular/common'], factory) :
    (global = typeof globalThis !== 'undefined' ? globalThis : global || self, factory(global["ngx-highlight-words"] = {}, global.ng.core, global.ng.common));
})(this, (function (exports, i0, i1) { 'use strict';

    function _interopNamespace(e) {
        if (e && e.__esModule) return e;
        var n = Object.create(null);
        if (e) {
            Object.keys(e).forEach(function (k) {
                if (k !== 'default') {
                    var d = Object.getOwnPropertyDescriptor(e, k);
                    Object.defineProperty(n, k, d.get ? d : {
                        enumerable: true,
                        get: function () { return e[k]; }
                    });
                }
            });
        }
        n["default"] = e;
        return Object.freeze(n);
    }

    var i0__namespace = /*#__PURE__*/_interopNamespace(i0);
    var i1__namespace = /*#__PURE__*/_interopNamespace(i1);

    /**
     * Creates an array of chunk objects representing both higlightable and non highlightable pieces of text that match each search word.
     * @return Array of "chunks" (where a Chunk is { start:number, end:number, highlight:boolean })
     */
    var findAll = function (_a) {
        var autoEscape = _a.autoEscape, _b = _a.caseSensitive, caseSensitive = _b === void 0 ? false : _b, _c = _a.findChunks, findChunks = _c === void 0 ? defaultFindChunks : _c, sanitize = _a.sanitize, searchWords = _a.searchWords, textToHighlight = _a.textToHighlight;
        return fillInChunks({
            chunksToHighlight: combineChunks({
                chunks: findChunks({
                    autoEscape: autoEscape,
                    caseSensitive: caseSensitive,
                    sanitize: sanitize,
                    searchWords: searchWords,
                    textToHighlight: textToHighlight,
                }),
            }),
            totalLength: textToHighlight ? textToHighlight.length : 0,
        });
    };
    /**
     * Takes an array of {start:number, end:number} objects and combines chunks that overlap into single chunks.
     * @return {start:number, end:number}[]
     */
    var combineChunks = function (_a) {
        var chunks = _a.chunks;
        // @ts-ignore
        return chunks
            .sort(function (first, second) { return first.start - second.start; })
            .reduce(function (processedChunks, nextChunk) {
            // First chunk just goes straight in the array...
            if (processedChunks.length === 0) {
                return [nextChunk];
            }
            else {
                // ... subsequent chunks get checked to see if they overlap...
                var prevChunk = processedChunks.pop();
                if (prevChunk && nextChunk.start <= prevChunk.end) {
                    // It may be the case that prevChunk completely surrounds nextChunk, so take the
                    // largest of the end indexes.
                    var endIndex = Math.max(prevChunk.end, nextChunk.end);
                    processedChunks.push({
                        highlight: false,
                        start: prevChunk.start,
                        end: endIndex,
                    });
                }
                else {
                    // @ts-ignore
                    processedChunks.push(prevChunk, nextChunk);
                }
                return processedChunks;
            }
        }, []);
    };
    /**
     * Examine text for any matches.
     * If we find matches, add them to the returned array as a "chunk" object ({start:number, end:number}).
     * @return {start:number, end:number}[]
     */
    var defaultFindChunks = function (_a) {
        var autoEscape = _a.autoEscape, caseSensitive = _a.caseSensitive, _b = _a.sanitize, sanitize = _b === void 0 ? defaultSanitize : _b, searchWords = _a.searchWords, textToHighlight = _a.textToHighlight;
        textToHighlight = sanitize(textToHighlight);
        return searchWords
            .filter(function (searchWord) { return searchWord; }) // Remove empty words
            .reduce(function (chunks, searchWord) {
            searchWord = sanitize(searchWord);
            if (autoEscape) {
                searchWord = escapeRegExpFn(searchWord);
            }
            var regex = new RegExp(searchWord, caseSensitive ? "g" : "gi");
            var match;
            while ((match = regex.exec(textToHighlight))) {
                var start = match.index;
                var end = regex.lastIndex;
                // We do not return zero-length matches
                if (end > start) {
                    // @ts-ignore
                    chunks.push({ highlight: false, start: start, end: end });
                }
                // Prevent browsers like Firefox from getting stuck in an infinite loop
                // See http://www.regexguru.com/2008/04/watch-out-for-zero-length-matches/
                if (match.index === regex.lastIndex) {
                    regex.lastIndex++;
                }
            }
            return chunks;
        }, []);
    };
    /**
     * Given a set of chunks to highlight, create an additional set of chunks
     * to represent the bits of text between the highlighted text.
     * @param chunksToHighlight {start:number, end:number}[]
     * @param totalLength number
     * @return {start:number, end:number, highlight:boolean}[]
     */
    var fillInChunks = function (_a) {
        var chunksToHighlight = _a.chunksToHighlight, totalLength = _a.totalLength;
        var allChunks = [];
        var append = function (start, end, highlight) {
            if (end - start > 0) {
                allChunks.push({
                    start: start,
                    end: end,
                    highlight: highlight,
                });
            }
        };
        if (chunksToHighlight.length === 0) {
            append(0, totalLength, false);
        }
        else {
            var lastIndex_1 = 0;
            chunksToHighlight.forEach(function (chunk) {
                append(lastIndex_1, chunk.start, false);
                append(chunk.start, chunk.end, true);
                lastIndex_1 = chunk.end;
            });
            append(lastIndex_1, totalLength, false);
        }
        return allChunks;
    };
    function defaultSanitize(string) {
        return string;
    }
    function escapeRegExpFn(string) {
        return string.replace(/[\-\[\]\/\{\}\(\)\*\+\?\.\\\^\$\|]/g, "\\$&");
    }

    var NgxHighlightWordsComponent = /** @class */ (function () {
        function NgxHighlightWordsComponent() {
            this.textToHighlight = "";
            this.searchWords = [];
            this.highlightClassName = "highlight";
            this.autoEscape = true;
            this.caseSensitive = false;
            this.findChunks = defaultFindChunks;
            this.sanitize = defaultSanitize;
        }
        Object.defineProperty(NgxHighlightWordsComponent.prototype, "chunks", {
            get: function () {
                return findAll({
                    textToHighlight: this.textToHighlight,
                    searchWords: this.searchWords,
                    autoEscape: this.autoEscape,
                    caseSensitive: this.caseSensitive,
                    findChunks: this.findChunks,
                    sanitize: this.sanitize,
                });
            },
            enumerable: false,
            configurable: true
        });
        return NgxHighlightWordsComponent;
    }());
    NgxHighlightWordsComponent.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0__namespace, type: NgxHighlightWordsComponent, deps: [], target: i0__namespace.ɵɵFactoryTarget.Component });
    NgxHighlightWordsComponent.ɵcmp = i0__namespace.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "12.2.13", type: NgxHighlightWordsComponent, selector: "ngx-highlight-words", inputs: { textToHighlight: "textToHighlight", searchWords: "searchWords", highlightClassName: "highlightClassName", autoEscape: "autoEscape", caseSensitive: "caseSensitive", findChunks: "findChunks", sanitize: "sanitize" }, ngImport: i0__namespace, template: "<span\n  [ngClass]=\"chunk.highlight ? highlightClassName : ''\"\n  *ngFor=\"let chunk of chunks\"\n  >{{ textToHighlight.substr(chunk.start, chunk.end - chunk.start) }}</span\n>\n", directives: [{ type: i1__namespace.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { type: i1__namespace.NgClass, selector: "[ngClass]", inputs: ["class", "ngClass"] }] });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0__namespace, type: NgxHighlightWordsComponent, decorators: [{
                type: i0.Component,
                args: [{
                        selector: "ngx-highlight-words",
                        templateUrl: "./ngx-highlight-words.component.html",
                    }]
            }], propDecorators: { textToHighlight: [{
                    type: i0.Input
                }], searchWords: [{
                    type: i0.Input
                }], highlightClassName: [{
                    type: i0.Input
                }], autoEscape: [{
                    type: i0.Input
                }], caseSensitive: [{
                    type: i0.Input
                }], findChunks: [{
                    type: i0.Input
                }], sanitize: [{
                    type: i0.Input
                }] } });

    var NgxHighlightWordsModule = /** @class */ (function () {
        function NgxHighlightWordsModule() {
        }
        return NgxHighlightWordsModule;
    }());
    NgxHighlightWordsModule.ɵfac = i0__namespace.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0__namespace, type: NgxHighlightWordsModule, deps: [], target: i0__namespace.ɵɵFactoryTarget.NgModule });
    NgxHighlightWordsModule.ɵmod = i0__namespace.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0__namespace, type: NgxHighlightWordsModule, declarations: [NgxHighlightWordsComponent], imports: [i1.CommonModule], exports: [NgxHighlightWordsComponent] });
    NgxHighlightWordsModule.ɵinj = i0__namespace.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0__namespace, type: NgxHighlightWordsModule, imports: [[i1.CommonModule]] });
    i0__namespace.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "12.2.13", ngImport: i0__namespace, type: NgxHighlightWordsModule, decorators: [{
                type: i0.NgModule,
                args: [{
                        declarations: [NgxHighlightWordsComponent],
                        imports: [i1.CommonModule],
                        exports: [NgxHighlightWordsComponent],
                    }]
            }] });

    /*
     * Public API Surface of ngx-highlight-words
     */

    /**
     * Generated bundle index. Do not edit.
     */

    exports.NgxHighlightWordsComponent = NgxHighlightWordsComponent;
    exports.NgxHighlightWordsModule = NgxHighlightWordsModule;

    Object.defineProperty(exports, '__esModule', { value: true });

}));
//# sourceMappingURL=ngx-highlight-words.umd.js.map
